/**
* \file CalibrationFrameTest.cc
 *
 * \brief Unit test of the calibration frame component.
 *
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: CalibrationFrameTest.cc,v 1.11 2005/03/16 00:04:03 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

#include "Instrument.h"
#include "CalibrationFrame.h"

using namespace gips;

int main()
{
    const int SIZE(100);
    blitz::Array<double,1> WN(SIZE);
    for (int i = 0; i < SIZE; ++i)
        WN(i) = i;
    const int TEST_FOLD_POINT(45);
    const instrument::band_t FAKE_BAND(WN, TEST_FOLD_POINT);
        
    const unsigned int NUM_PASSES(2);
    Lin4BbFrameGenerator frameGen(FAKE_BAND, NUM_PASSES, "FAKE");
    vector<FramePtr> frames;
    // push fake spectra at the frameGen
    for (int i = 0; i < 100; ++i)
    {
        blitz::Array<complex<double>,1> fakeBb(SIZE);
        for (int j = 0; j < SIZE; ++j)
            fakeBb(j) = (double)(i * 100 + j);

        bool isReady = frameGen.processSpectrum(fakeBb, static_cast<physics::seconds_t>(i));
        if (isReady)
            frames.push_back(frameGen.getFrame());
    }
    
    blitz::Array<complex<double>,1> out(SIZE);
    if(frames[0]->compareTime(5) == Frame::IN_FRAME)
        frames[0]->getSpectrumAt(5, out);
    if(frames[10]->compareTime(10) == Frame::IN_FRAME)
        frames[10]->getSpectrumAt(10, out);
    
    return 0;
}
