/**
* \file Planck.cc
 * Planck curve utility library implementation
 *
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 * \version $Id: Planck.cc,v 1.3 2005/01/20 20:45:33 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2005
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

#include <math.h>
#include "Planck.h"

using namespace gips;

void Planck::rad2bt(const blitz::Array<double,1> &rad, blitz::Array<double,1> &bt)
{
    bt = c2 * wn / (log(1.0 + c1 * (wn * wn * wn) / (rad / 1000)));
};

void Planck::bt2rad(const blitz::Array<double,1> &bt, blitz::Array<double,1> &rad)
{
    rad = 1000.0 * c1 * (wn * wn * wn) / (exp((c2 * wn) / bt) - 1.0);
};

void Planck::B(const double &t, blitz::Array<double,1> &rad)
{
    temp = zeros + t;
    bt2rad(temp, rad);
};
