/**
* \file Planck.h
 * Planck curve utility library
 *
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 * \version $Id: Planck.h,v 1.4 2005/01/31 09:12:14 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2005
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

#ifndef H_PLANCK
#define H_PLANCK

#include <blitz/array.h>

namespace gips
{

class Planck
{
private:
    static const double h = 6.62606876E-34;
    static const double c = 2.99792458E8;
    static const double k = 1.3806503E-23;
    
    static const double c1 = 2*h*c*c*1e8;
    static const double c2 = h*c/k*1e2;
    
    const blitz::Array<double,1> wn;
    const blitz::Array<double,1> zeros;
    blitz::Array<double,1> temp;   // buffer to hold constant temperature (bt).
    
public:
    explicit Planck(const blitz::Array<double,1> wavenumbers): wn(wavenumbers), 
        zeros(wavenumbers.size()),
        temp(wavenumbers.size()) 
    {};
    ~Planck(){};
    
    void rad2bt(const blitz::Array<double,1> &rad, blitz::Array<double,1> &bt);
    void bt2rad(const blitz::Array<double,1> &bt, blitz::Array<double,1> &rad);
    void B(const double &t, blitz::Array<double,1> &rad);
};
}

#endif
