/** 
*  \file RadCalOperatorTest.h
*  \brief Unit test for radiometric calibration operator. 
*    
*  \author M.J.Smuga-Otto <maciek@ssec.wisc.edu>
*
*  \version $Id: RadCalOperatorTest.cc,v 1.4 2005/03/11 21:24:33 maciek Exp $
*
*  \par Copyright:
*  \verbatim
*
*  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
*  Space Science and Engineering Center
*  University of Wisconsin - Madison, USA
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
*  \endverbatim
*/

#include <blitz/array.h>
#include "RadCalOperator.h"

using namespace gips;

/** 
*  \file RadCalOperatorTest.h
*  \brief Unit test for radiometric calibration operator. 
*    
*  \author M.J.Smuga-Otto <maciek@ssec.wisc.edu>
*
*  \version $Id: RadCalOperatorTest.cc,v 1.4 2005/03/11 21:24:33 maciek Exp $
*
*  \par Copyright:
*  \verbatim
*
*  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
*  Space Science and Engineering Center
*  University of Wisconsin - Madison, USA
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
*  \endverbatim
*/

#include <blitz/array.h>
#include "RadCalOperator.h"

using namespace gips;
using std::complex;

int main()
{
    const int SIZE(200);
    const blitz::Array<complex<double>,1> obs(SIZE);
    const blitz::Array<complex<double>,1> hbb(SIZE);
    const blitz::Array<complex<double>,1> abb(SIZE);
    const blitz::Array<double,1> thbb(SIZE);
    const blitz::Array<double,1> tabb(SIZE);
    blitz::Array<complex<double>,1> diagOut(SIZE);
    blitz::Array<double,1> obsOut(SIZE);
    
    Operator::Result res = RadiometricCalibrationOperator(obs, hbb, abb, thbb, tabb, diagOut, obsOut);
    assert(res == Operator::OK);
    return 0;
}
