#include "Instrument.h"
#include <string>

namespace gips {
    namespace instrument {
	
	// for SHIS, fold points are (courtesy of <eriko@ssec.wisc.edu>): 
	static const int SHIS_LW_FOLDPOINT = 829;
	static const int SHIS_MW_FOLDPOINT = 1241;
	static const int SHIS_SW_FOLDPOINT = 2899;
	
	static const int SHIS_LW_SIZE = 2044;
	static const int SHIS_MW_SIZE = 4088;
	static const int SHIS_SW_SIZE = 4088;
	
	int getBandSize(const string& bandName)
	{
	    if (bandName == "LW")
		return SHIS_LW_SIZE;
	    else if (bandName == "MW")
		return SHIS_MW_SIZE;
	    else if (bandName == "SW")
		return SHIS_SW_SIZE;
	    assert("band name must be LW, MW or SW\n");
	    return 0;
	};

	int getBandFoldPoint(const string& bandName)
	{
	    if (bandName == "LW")
		return SHIS_LW_FOLDPOINT;
	    else if (bandName == "MW")
		return SHIS_MW_FOLDPOINT;
	    else if (bandName == "SW")
		return SHIS_SW_FOLDPOINT;
	    assert("band name must be LW, MW or SW\n");
	    return 0;
	};
        
	ScanDirection getScanDir(const string& sdStr)
	{
	    return sdStr == "FW" ? FW : BW;
	};
	
	string scanDirStr(ScanDirection sd)
	{ 
	    return sd == FW ? "FW" : "BW";
	}

	ObservationType getObsType(const string& otStr)
	{
	    if (otStr == "AMBIENT")
		return AMBIENT;
	    if (otStr == "HOT")
		return HOT;
	    if (otStr == "OBS")
		return SCENE;
	    if (otStr == "SPACE")
		return SPACE;
	    // default
	    return INVALID;
	};  
    };
};
