//
// Memory Map Wrapper class
// Maciek Smuga-Otto, 2005
// 

#ifndef MMAP_WRAP_H
#define MMAP_WRAP_H

#include <sys/types.h>
#include <sys/mman.h> 

#include <iostream>

template <typename T>
class MmapWrap
{
private:
    T *tp;
    int ct;
public:
    // ctor, dtor
    explicit MmapWrap(int fd, int count, bool writable=false);
    ~MmapWrap();

    // array-style access
    T& operator[](int index);
    const T& operator[](int index) const;

    // getting at the raw guts
    T* getRawPtr() const;
    int getCount() const;
private:
    // no copy constructor or operator semantics provided 
    // due to external resource stewardship
    MmapWrap(const MmapWrap&); 
    MmapWrap& operator=(const MmapWrap&);
};

template <typename T>
MmapWrap<T>::MmapWrap(int fd, int count, bool writable)
{
    int accessFlags = writable ? (PROT_READ | PROT_WRITE) : PROT_READ;
    tp = static_cast<T*>(mmap(NULL, sizeof(T) * count, accessFlags, MAP_SHARED, fd, 0));
    ct = count;
    assert(tp);
};

template <typename T>
MmapWrap<T>::~MmapWrap()
{
    try
    {
	int ret=munmap((void *)tp, sizeof(T) * ct);
	cerr << "munmap return status: " << ret << endl;
    }
    catch(...)
    {
	cerr << "munmap threw exception" << endl;
    } // catchall: destructor must never throw
}

template <typename T>
T& MmapWrap<T>::operator[](int index)
{
    assert(index < ct);
    return *(tp + index);
}

template <typename T>
const T& MmapWrap<T>::operator[](int index) const
{
    assert(index < ct);
    return const_cast<const T&>(*(tp + index));
}

template <typename T>
T* MmapWrap<T>::getRawPtr() const
{
    return tp; // return by value
}

template <typename T>
int MmapWrap<T>::getCount() const
{
    return count; // return by value
}

#endif
