/*
 * \file CplxFFTTest.cc
 * \brief unit test for CplxFFT operator
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: CplxFFTTest.cc,v 1.13 2005/03/04 23:05:56 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

#include <complex>

#include "CplxFFT.h"
#include "Connector.h"

using namespace gips;
using namespace CplxFFT;

using std::complex;


/// \todo get the const stuff sorted out
Config defaultConfig(1024);

Operator::Result testOperator( )
{
    // data in & out
    blitz::Array<complex<double>, 1> blitzIn(1024);
    Connector::BlitzOpenConnector<complex<double> > testIn(blitzIn);
    
    blitz::Array<complex<double>, 1> blitzOut(1024);
    Connector::BlitzOpenConnector<complex<double> > testOut(blitzOut);
    
    Connector::ConstantInputPort<Config> testConfig(defaultConfig);
        
    // invoke operator with the correct ports
    Ports ports(testIn, testOut, testConfig);

    CplxFFTOperator op(ports);
    Operator::Result res = op();
    
    return res;
}; // testOperator()

int main()
{
    Operator::Result rc = testOperator();
    assert(rc == Operator::OK);
    return(0);
}

