/*
 * \file SHIS_Ifg2SpectrumTest.cc
 * \brief unit test for SHISStage subclass of Ifg2SpectrumStage
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: SHIS_Ifg2SpectrumTest.cc,v 1.19 2005/03/08 22:53:41 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

// how to test the nonlinearity correction operator?
// for one thing, we need some ersatz connectors that provide
// data from a compile-time allocated memory cache, and read back
// into another one (at least for the unit tests)


// C++ STL includes
#include <string>
#include <vector>
#include <iostream> // std::cerr

// other support library includes
#include <boost/shared_ptr.hpp>
#include "FBF.h"
#include "clok.h"

// GIPS framework includes
#include "Ifg2Spectrum.h"
#include "Connector.h"

using namespace std;
using namespace gips;
using namespace Ifg2Spectrum;
    
Operator::Result livelinessTest()
{
    // data in & out
    blitz::Array<complex<double>, 1> blitzIn(1024);
    Connector::BlitzOpenConnector<complex<double> > testIn(blitzIn);
    
    blitz::Array< complex<double>, 1> blitzOut(1024);
    Connector::BlitzOpenConnector<complex<double> > testOut(blitzOut);
    
    // configuration - used at initialization of stage and operators
    Config defaultConfig(1024, 512);
    Connector::ConstantInputPort<Config> testConfig(defaultConfig);
    
    Ports ports(testIn, testOut, testConfig);

    boost::shared_ptr<Ifg2SpectrumStage> stageptr = Ifg2SpectrumStage::Factory(instrument::SHIS_V0, ports);
    Operator::Result res = (*stageptr)();
    
    return res;
}; // testOperator()


int main()
{
    Operator::Result rc;
    rc = livelinessTest();
    assert(rc == Operator::OK);
    return(0);
}

