/**
 * \file SpectrumFold.cc
 * \brief SHIS implementation of SpectrumFold operator
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 * based directly on the Scanning-HIS rsh2fbf application, written by Ray Garcia <rayg@ssec.wisc.edu>
 *
 *  \version $Id: SpectrumFold.cc,v 1.18 2005/03/24 21:37:03 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

#include "SpectrumFold.h"


namespace gips {
namespace SpecFold {

Operator::Result SpecFoldOperator::operator() ( )
{
    //std::cerr << "in spectrum fold operator" << std::endl;
    const instrument::BlitzCplxDoubleVector& in( ports.prefoldedSpectrum.getForInput() );
    instrument::BlitzCplxDoubleVector& out( ports.foldedSpectrum.getForOutput() );
    const Config& config( ports.config.getForInput() );
    
    assert(config.npts && config.npts >= config.foldPoint);
    int N(config.npts);
    int poldFoint(N - config.foldPoint - 1);
    
    //std::cerr << "spectrumFold input channels 0,10,200: " << in(0) << "," << in(10) << "," << in(200) << std::endl;
    //if ( !N || N < config.foldPoint ) 
    //    return Operator::WARNING;

    int dest(0);
    for (int src(poldFoint); src >= 0; --src, ++dest) {
        //std::cerr << ".";
        out(dest) = in(src);
    }
    // dest is now at poldFoint
    //std::cerr << ":" << std::endl;
    for (int src(N-1); src > poldFoint; --src, ++dest) {
        //std::cerr << "*";
        out(dest) = in(src);
    }
    //std::cerr << ";" << std::endl;
    
    //std::cerr << "spectrumFold output channels 0,10,200: " << out(0) << "," << out(10) << "," << out(200) << std::endl;

    return Operator::OK;
}; // operator() 
        
} }// namespace

/******************** original function body in rsh2fbf:
int sol1SpcFold( solContent &out, const solContent &in, unsigned foldPoint ) { 
    // flip source end for end, around fold point
    // for poldFoint = N-1 - foldPoint...:
    // a...b <poldFoint> c....d transforms to
    // b...a <poldFoint> d....c
    
    out.resize( in.size() );
    int N = in.size() / 2;    
    int poldFoint=N-1-foldPoint;
    if (!N || N<(int)foldPoint) return 1;
    // unsigned src, dest;
    int src, dest = 0;
    for( src = poldFoint; src>=0; src--,dest++ ) {      
        out[dest*2] = in[src*2];
        out[(dest*2)+1] = in[(src*2)+1];
    }
    // dest = poldFoint...
    for( src=N-1; src>poldFoint; src--, dest++ ) {
        out[dest*2] = in[src*2]; 
        out[(dest*2)+1] = in[(src*2)+1];
    }
    return 0;
}

int sol1SpcFold( solComplexRads &out, const solComplexRads &in, sol1SpcFold_status &s ) {
    int rc = 0;
    for( unsigned i=0; i<IFG4_BANDS; i++ ) 
        if (!s.suppress[i]) 
            rc |= sol1SpcFold( out.qi[i], in.qi[i], s.foldPoint[i] );
    return rc;
}
*********************/


