/**
 * \file L0L1Pipeline_SHISv0Test.h
 * \brief unit test for SHIS pipeline.
 *
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 * unit test for SHISv0 Pipeline code.
 *
 *  \version $Id: L0L1Pipeline_SHISv0Test.cc,v 1.8 2005/03/16 00:04:03 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 *
 */

#include <iostream>
#include "blitz/array.h"
#include "boost/shared_ptr.hpp"

#include "Instrument.h"
#include "Connector.h"
#include "L0L1Pipeline.h"

using namespace std;
using namespace gips;

int main()
{
    // connectors, connectors!
    const int SIZE(100);
    
    // settings port
    blitz::Array<double,1> WN(SIZE);
    for (int i = 0; i < SIZE; ++i)
        WN(i) = i;
    const int TEST_FOLD_POINT(45);
    const instrument::band_t TEST_BAND(WN, TEST_FOLD_POINT);
    const unsigned int TEST_BBPASSES(2);

    L0L1Pipeline::Settings testSettings(TEST_BAND, TEST_BBPASSES);

    L0L1Pipeline::Ancillary testAncil;
    L0L1Pipeline::SpectralCalAncillary testSpectralAncil;
    L0L1Pipeline::RadiometricCalAncillary testRadiometricAncil;
    L0L1Pipeline::Audit testAudit;

    blitz::Array<complex<double>,1> testIn(1, SIZE);
    blitz::Array<complex<double>,1> testDiag(1, SIZE);
    blitz::Array<double,1> testOut(1, SIZE);

    testIn = 0; // should zero these out
    testOut = 0;
    testDiag = 0;

    Connector::SimpleConnector<L0L1Pipeline::Settings> settingsConn(testSettings);
    Connector::SimpleConnector<L0L1Pipeline::Ancillary> ancilConn(testAncil);
    Connector::SimpleConnector<L0L1Pipeline::SpectralCalAncillary> spectralAncilConn(testSpectralAncil);
    Connector::SimpleConnector<L0L1Pipeline::RadiometricCalAncillary> radiometricAncilConn(testRadiometricAncil);
    Connector::SimpleConnector<L0L1Pipeline::Audit> auditConn(testAudit);
    
    Connector::BlitzOpenConnector<complex<double> > dataInConn(testIn);
    Connector::BlitzOpenConnector<complex<double> > dataDiagConn(testDiag);
    Connector::BlitzOpenConnector<double> dataOutConn(testOut);

    L0L1Pipeline::Ports testPorts(dataInConn, dataOutConn, settingsConn, 
				  ancilConn, spectralAncilConn, radiometricAncilConn, dataDiagConn, auditConn);

    boost::shared_ptr<L0L1Pipeline> pipeline = L0L1Pipeline::Factory(instrument::SHIS_V0, testPorts);

    cout << testIn << endl << testOut << endl << testDiag << endl;

    Operator::Result pipelineRes = (*pipeline)();
    assert(pipelineRes == Operator::OK);
    cout << testIn << endl << testOut << endl << testDiag << endl;
    return 0;
};
